@@ -15,4 +15,4 @@ def open(q, ex):
 
     open(2, 10, IFrame) открывает q2.10
     """
-    return IFrame(f'q{q}-{ex}.pdf', width=600, height=300)
+    return IFrame(f'./q{q}-{ex}.pdf', width=600, height=300)
